@@ -15,8 +15,9 @@ import sys, getopt
 #from oauthlib.oauth2 import BackendApplicationClient
 
 from inforion.ionapi.basic import load_config,login,header
-from inforion.ionapi.MMS import AddItmBasic,MMS021,MMS021bulk,MMS021bulk2,CRS610bulk,CRS610,CRS610bulk2
+from inforion.ionapi.MMS import AddItmBasic,MMS021,MMS021bulk,MMS021bulk2,CRS610bulk,CRS610,CRS610bulk2,bulk
 
+from inforion.helper.urlsplit import spliturl
 def main():
     print ('Main')
     method =''
@@ -24,12 +25,14 @@ def main():
     print (argv)
     help_string = "Usage:\n./%s -u URL -f IONFile -m method"
     try:
-        opts, args = getopt.getopt(argv, "h:u:f:m:i:o:s:e:", ["url", "ionfile","method","inputfile","outputfile","start","end"])
+        opts, args = getopt.getopt(argv, "h:u:f:p:m:i:o:s:e:", ["url", "ionfile","program""method","inputfile","outputfile","start","end"])
 
     except getopt.GetoptError:
         print (help_string)
         sys.exit(2)
 
+
+
     for opt, arg in opts:
 
         if arg == ("-h", "help"):
@@ -42,6 +45,8 @@ def main():
             ionfile = arg
         elif opt in ("-m", "--method"):
             method = arg   
+        elif opt in ("-p", "--program"):
+            program = arg   
         elif opt in ("-i", "--inputfile"):
             inputfile = arg 
         elif opt in ("-o", "--outputfile"):
@@ -50,6 +55,21 @@ def main():
             start = int(arg)
         elif opt in ("-e", "--end"):
             end = int(arg)
+   
+    result = spliturl(url)
+
+    if "Call" in result:
+        if len(result["Call"]) > 0:
+            if result["Call"] == "execute":
+
+                config = load_config(ionfile)
+                token=login(url,config)
+                
+                headers = header(config,token)
+                if "Bearer"  not in headers['Authorization']:
+                    return "InforION Login is not working"
+                #return CRS610bulk(url,headers,inputfile,'CRS610MI',outputfile,start,end)
+                return bulk(url,headers,program,method,inputfile,outputfile,start,end)  
 
     if method == "checklogin":
         config = load_config(ionfile)
@@ -58,6 +78,9 @@ def main():
           
         if "Bearer" in headers['Authorization']:
             return "InforION Login is working"
+    
+    
+    '''
     elif method == "MMS200MI":
         config = load_config(ionfile)
         token=login(url,config)
@@ -82,7 +105,7 @@ def main():
         config = load_config(ionfile)
         token=login(url,config)
         headers = header(config,token)
-        return CRS610bulk(url,headers,inputfile,'CRS610MI',outputfile,1001,2000)
+        return CRS610bulk(url,headers,inputfile,'CRS610MI',outputfile,start,end)
     elif method == "CRS610bulk2":
         config = load_config(ionfile)
         token=login(url,config)
@@ -93,8 +116,10 @@ def main():
         token=login(url,config)
         headers = header(config,token)
         return CRS610(url,headers,inputfile,'out.xslx')
+    
     else:
         return ('Sorry you need to define a method plese use inforion -h')
+    '''
 
 if __name__ == "__main__":
     #sys.exit(run("-h"))
